@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: configure Dist::Zilla like RUSSOZ
-our $VERSION = '0.022';    # VERSION
+our $VERSION = '0.023';    # VERSION
 
 use Moose 0.99;
 use namespace::autoclean 0.09;
@@ -44,7 +44,7 @@ sub _build_version_types {
         'none'    => sub { },
         'auto'    => sub { $self->add_plugins('AutoVersion') },
         'gitnext' => sub { $self->add_plugins('Git::NextVersion') },
-        'module'  => sub { $self->add_plugins('VersionFromModule') },
+        'module'  => sub { $self->add_plugins('VersionFromMainModule') },
     };
 }
 
@@ -132,9 +132,9 @@ sub configure {
 
     # Basic sans upload
     $self->add_plugins(
-        'GatherDir', 'PruneCruft', 'ManifestSkip', 'MetaYAML',
-        'License',   'ExtraTests', 'ExecDir',      'ShareDir',
-        'MakeMaker', 'Manifest',   'TestRelease',  'ConfirmRelease',
+        'GatherDir', 'PruneCruft',  'ManifestSkip', 'MetaYAML',
+        'License',   'ExecDir',     'ShareDir',     'MakeMaker',
+        'Manifest',  'TestRelease', 'ConfirmRelease',
     );
     $self->fake
       ? $self->add_plugins('FakeRelease')
@@ -171,7 +171,7 @@ sub configure {
 
         $self->add_plugins('Test::UseAllModules');
         $self->add_bundle( 'TestingMania' =>
-              { disable => [ 'Test::CPAN::Changes', 'Test::Synopsis' ], } );
+              { disable => [ 'Test::CPAN::Changes', 'Test::Synopsis', ], } );
         $self->add_plugins('Test::Pod::No404s')
           if ( $self->use_no404 || $ENV{NO404} );
     }
@@ -188,11 +188,11 @@ no Moose;
 
 1;
 
-
+__END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -200,7 +200,7 @@ Dist::Zilla::PluginBundle::Author::RUSSOZ - configure Dist::Zilla like RUSSOZ
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 SYNOPSIS
 
@@ -253,242 +253,75 @@ a L<Dist::Zilla> configuration approximately like:
 	[ReportPhase]                       ; if report = 1
 	[@Git]
 
+=head1 NAME
+
+Dist::Zilla::PluginBundle::Author::RUSSOZ - configure Dist::Zilla like RUSSOZ
+
+=head1 VERSION
+
+version 0.023
+
+=head1 TASK CONTENTS
+
 =head1 USAGE
 
 Just put C<[@Author::RUSSOZ]> in your F<dist.ini>. You can supply the following
 options:
 
-=over 4
-
-=item *
-
-version
-
+=for :list * version
 How to handle version numbering. Possible values: none,
 auto (will use L<Dist::Zilla::Plugin::AutoVersion>),
 gitnext (will use Dist::Zilla::Plugin::Git::NextVersion).
 Default = none.
-
-=item *
-
-auto_prereqs
-
+* auto_prereqs
 Whether the module will use C<AutoPrereqs> or not. Default = 1.
-
-=item *
-
-github
-
+* github
 If using github, enable C<[GithubMeta]>. Default = 1.
-
-=item *
-
-use_no404
-
+* use_no404
 Whether to use C<[Test::Pod::No404]> in the distribution. Default = 0.
-
-=item *
-
-task_weaver
-
+* task_weaver
 Set to 1 if this is a C<Task::> distribution. It will enable C<[TaskWeaver]>
 while disabling C<[PodWeaver]> and all release tests. Default = 0.
-
-=item *
-
-fake
-
+* fake
 Set to 1 if this is a fake release. It will disable [UploadToCPAN] and
 enable [FakeRelease]. It can also be enabled by setting the environemnt
 variable C<FAKE>. Default = 0.
-
-=item *
-
-signature
-
+* signature
 Whether to GPG sign the module or not. Default = 1.
-
-=item *
-
-report
-
+* report
 Whether to report the Dist::Zilla building phases. Default = 0.
 
-=back
-
 =for Pod::Coverage configure
 
+=head1 SEE ALSO
+
+C<< L<Dist::Zilla> >>
+
 =head1 ACKNOWLEDGMENTS
 
 Much of the first implementation was shamelessly copied from
 C<Dist::Zilla::PluginBundle::Author::DOHERTY>.
 
-=head1 SEE ALSO
-
-Please see those modules/websites for more information related to this module.
-
-=over 4
-
-=item *
-
-L<C<< L<Dist::Zilla> >>|C<< L<Dist::Zilla> >>>
-
-=back
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
-
-=head1 SUPPORT
-
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc Dist::Zilla::PluginBundle::Author::RUSSOZ
-
-=head2 Websites
-
-The following websites have more information about this module, and may be of help to you. As always,
-in addition to those websites please use your favorite search engine to discover more resources.
-
-=over 4
-
-=item *
-
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/Dist-Zilla-PluginBundle-Author-RUSSOZ>
-
-=item *
-
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/Dist-Zilla-PluginBundle-Author-RUSSOZ>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Dist-Zilla-PluginBundle-Author-RUSSOZ>
-
-=item *
-
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/Dist-Zilla-PluginBundle-Author-RUSSOZ>
-
-=item *
-
-CPANTS
-
-The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
-
-L<http://cpants.perl.org/dist/overview/Dist-Zilla-PluginBundle-Author-RUSSOZ>
-
-=item *
-
-CPAN Testers
-
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
-
-L<http://www.cpantesters.org/distro/D/Dist-Zilla-PluginBundle-Author-RUSSOZ>
-
-=item *
-
-CPAN Testers Matrix
-
-The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
-
-L<http://matrix.cpantesters.org/?dist=Dist-Zilla-PluginBundle-Author-RUSSOZ>
-
-=back
-
-=head2 Email
-
-You can email the author of this module at C<RUSSOZ at cpan.org> asking for help with any problems you have.
-
-=head2 Internet Relay Chat
-
-You can get live help by using IRC ( Internet Relay Chat ). If you don't know what IRC is,
-please read this excellent guide: L<http://en.wikipedia.org/wiki/Internet_Relay_Chat>. Please
-be courteous and patient when talking to us, as we might be busy or sleeping! You can join
-those networks/channels and get help:
-
-=over 4
-
-=item *
-
-irc.perl.org
-
-You can connect to the server at 'irc.perl.org' and join this channel: #sao-paulo.pm then talk to this person for help: russoz.
-
-=back
-
-=head2 Bugs / Feature Requests
-
-Please report any bugs or feature requests by email to C<bug-dist-zilla-pluginbundle-author-russoz at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dist-Zilla-PluginBundle-Author-RUSSOZ>. You will be automatically notified of any
-progress on the request by the system.
-
-=head2 Source Code
-
-The code is open to the world, and available for you to hack on. Please feel free to browse it and play
-with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
-from your repository :)
-
-L<https://github.com/russoz/Dist-Zilla-PluginBundle-Author-RUSSOZ>
-
-  git clone https://github.com/russoz/Dist-Zilla-PluginBundle-Author-RUSSOZ.git
-
 =head1 AUTHOR
 
 Alexei Znamensky <russoz@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Alexei Znamensky.
+This software is copyright (c) 2011 - 2017 by Alexei Znamensky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 BUGS AND LIMITATIONS
+=head1 AUTHOR
 
-You can make new bug reports, and view existing ones, through the
-web interface at L<http://rt.cpan.org>.
+Alexei Znamensky <russoz@cpan.org>
 
-=head1 DISCLAIMER OF WARRANTY
+=head1 COPYRIGHT AND LICENSE
 
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
-WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
-PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
-EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
-IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
-SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
-THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
+This software is copyright (c) 2011 - 2017 by Alexei Znamensky.
 
-IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
-TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
-SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
-DAMAGES.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
-
